@@ -21,6 +21,8 @@ from ray.serve.api import Client as ServeClient
 from ray.serve.exceptions import RayServeException
 from starlette.requests import Request
 
+import logging
+
 TRAINERS = {'ppo': PPOTrainer, 'appo': APPOTrainer, 'ddpo': DDPPOTrainer, 'dqn': DQNTrainer, 'apex_dqn': ApexTrainer}
 
 _SHELL = os.getenv('SHELL')
@@ -105,6 +107,7 @@ def deploy_policy(backend_server: ServeClient, trainer_id: int, policy_id: int,
     class ServeModel:
         def __init__(self, agent_config: dict, checkpoint_path: str, trainer_path: str, model_name: str, agent_type: str):
 
+            # logging.basicConfig(filename=os.path.expanduser('~')+'/lairning/log.log', level=logging.INFO)
             sim_path = '{}.models.{}'.format(trainer_path, model_name)
             exec_locals = {}
             try:
@@ -122,13 +125,14 @@ def deploy_policy(backend_server: ServeClient, trainer_id: int, policy_id: int,
                                           "sim_model": exec_locals['SimModel'],
                                           "sim_config": exec_locals['BASE_CONFIG']}
 
-            # checkpoint_path = trainer_path + checkpoint_path[1:]
+            checkpoint_path = os.path.expanduser('~')+"/lairning/" + trainer_path + checkpoint_path[1:]
+
+            # logging.info(checkpoint_path)
 
             trainer_class = TRAINERS[agent_type]
 
             self.trainer = trainer_class(config=agent_config)
             self.trainer.restore(checkpoint_path)
-            # self.trainer.restore("~/lairning/" + checkpoint_path)
 
         async def __call__(self, request: Request):
             try:
